==> haskell-http-types-0.12.4-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-types
version:              0.12.4
visibility:           public
id:                   http-types-0.12.4-BHydc54DAW314d9zE8t9hR
key:                  http-types-0.12.4-BHydc54DAW314d9zE8t9hR
license:              BSD-3-Clause
copyright:            (C) 2011 Aristid Breitkreuz
maintainer:           felix.paulusma@gmail.com
author:               Aristid Breitkreuz, Michael Snoyman
homepage:             https://github.com/Vlix/http-types
synopsis:
    Generic HTTP types for Haskell (for both client and server code).

description:
    Types and functions to describe and handle HTTP concepts.
    Including "methods", "headers", "query strings", "paths" and "HTTP versions".

category:             Network, Web
abi:                  05c83abb7aeb0b4946ecb0054dd492b9
exposed:              True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version

import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-types-0.12.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-types-0.12.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-types
hs-libraries:         HShttp-types-0.12.4-BHydc54DAW314d9zE8t9hR
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-GWeOjNQL6o11YPoz7mZGER text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html:         /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-types-0.12.4-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-types
version:              0.12.4
visibility:           public
id:                   http-types-0.12.4-54A2bJ1fQUxAhnyu8WH6Th
key:                  http-types-0.12.4-54A2bJ1fQUxAhnyu8WH6Th
license:              BSD-3-Clause
copyright:            (C) 2011 Aristid Breitkreuz
maintainer:           felix.paulusma@gmail.com
author:               Aristid Breitkreuz, Michael Snoyman
homepage:             https://github.com/Vlix/http-types
synopsis:
    Generic HTTP types for Haskell (for both client and server code).

description:
    Types and functions to describe and handle HTTP concepts.
    Including "methods", "headers", "query strings", "paths" and "HTTP versions".

category:             Network, Web
abi:                  2c7a94ab149095043b5ddd1c2369b5a0
exposed:              True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version

import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-types-0.12.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-types-0.12.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-types
hs-libraries:         HShttp-types-0.12.4-54A2bJ1fQUxAhnyu8WH6Th
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-GWeOjNQL6o11YPoz7mZGER text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html:         /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
